@@ -7,7 +7,8 @@ class Camera {
  public:
   Coord center,eyes,up;
   double zoomFactor;
-  Camera(Coord center=Coord(0,0,-1),Coord eyes=Coord(0,0,0), Coord up=Coord(0,1,0), double zoomFactor=1);
+  double sceneRadius;
+  Camera(Coord center=Coord(0,0,-1),Coord eyes=Coord(0,0,0), Coord up=Coord(0,1,0), double zoomFactor=1, double sceneRadius=1);
   /// This moves the camera forward or backward depending on the speed
   void move(float speed);
   ///  This strafes the camera left and right depending on the speed (-/+)
