@@ -34,11 +34,13 @@
 #include <tulip/Types.h>
 #include <tulip/TemplateFactory.h>
 #include <tulip/Reflect.h>
+#include <tulip/MutableContainer.h>
 
 #include <tulip/tulipconf.h>
 #include "tulip/Camera.h"
 #include "tulip/GlGraphStrategy.h"
-#include "tulip/Rectangle.h"
+#include "tulip/OcclusionTest.h"
+#include "tulip/ObservableGlGraph.h"
 
 class LayoutProxy;
 class MetricProxy;
@@ -48,128 +50,62 @@ class SelectionProxy;
 class SizesProxy;
 class ColorsProxy;
 class MetaGraphProxy;
-class PropertyProxyContainer;
-
+class PropertyManager;
 class Glyph;
 class GlyphFactory;
 class GlyphContext;
-class ListRectangleInt2D;
-
-typedef STL_EXT_NS::hash_map<int, std::string, STL_EXT_NS::hash<int> > GlyphTableString;
-typedef STL_EXT_NS::hash_map<int, Glyph *, STL_EXT_NS::hash<int> > GlyphTableGlyph;
+class OcclusionTest;
+class PluginLoader;
 
 
-struct RectangleInt2D : public tlp::geo::Rectangle<unsigned int> {
-  RectangleInt2D(unsigned int x,unsigned int y,unsigned int x1,unsigned int y1) {
-    (*this)[0][0]=x;
-    (*this)[0][1]=y;
-    (*this)[1][0]=x1;
-    (*this)[1][1]=y1;
-  }
-  RectangleInt2D(const RectangleInt2D &r):tlp::geo::Rectangle<unsigned int>(r){}
-};
-
-struct ListRectangleInt2D {
-  std::vector<RectangleInt2D> data;
-  void reset() {
-    data.clear();
-  }
-  bool addRectangle(const RectangleInt2D &rec) {
-    bool intersect=false;
-    std::vector<RectangleInt2D>::const_iterator it;
-    for (it=data.begin();it!=data.end();++it) {
-      if (rec.intersect(*it)) {
-	intersect=true;
-	break;
-      }
-    }
-    if (!intersect) data.push_back(rec);
-    return intersect;
-  }
-};
+enum DrawState {DRAWEDGE = 0, DRAWNODE = 1, DRAWSELECTEDNODELABELS = 2, DRAWSELECTEDEDGELABELS = 3,
+		DRAWNODELABELS = 4 , DRAWEDGELABELS = 5 , DRAWEND = 6};
 
 /**
  * This widget enables an incremental 3D drawing of a Tulip SuperGraph.
  *  It also includes 3D navigation capabilities and selection methods.
  *  All the displaying is done with OpenGl.
  */
-class GlGraph {
-private:
-  GlGraphStrategy *strategy;
-
-  //we will never have to get a copy of that GlGraph.
-  //GlGraph objects should be only passed by reference or pointer
-  GlGraph(const GlGraph &);
+class GlGraph : public GraphObserver, public ObservableGlGraph {
   
 public:
   GlGraph(GlGraphStrategy &strategy);
   GlGraph(GlGraphStrategy &strategy, const GlGraph &);
   ~GlGraph();
-
+  //============================================
+  /**
+   * This function must be call before using the opengl
+   * rendering engine.
+   */
+  void initializeGL();
   //============================================
   DataSet getParameters() const;
   void setParameters(const DataSet);
-  
   /**
    *  Initialize scale factors according to layout bounding box
-   *  Initialize the camera position.
+   *  and the camera position in order to have the graph at the 
+   *  center of the screen
    */
-  void init();
-  
-  /**
-   * sets the glyph table
-   * \param v hash of integer to symbolic glyph name (a string)
-   \sa GlyphTableString
-   */
-  void setGlyphTable(const GlyphTableString &v);
-  
-  /**
-   * sets the glyph table
-   * \param v hash of integer to Glyph object
-   * \sa GlyphTableGlyph
-   */
-  void setGlyphTable(const GlyphTableGlyph &v);
-  GlyphTableString getGlyphTable() const;
-  
-  /// Rebuild the OpenGl Display lists
-  void updateList();
-  
-  /**
-   * Initialize OpenGl renderer parameters
-   * GL_LINE_SMOOTH,GL_BLEND,GL_CULL_FACE,GL_DEPTH_TEST
-   */
-  void initializeGL();
-  
-  /**
-   *  Set ligths, clipping plane, camera position, 
-   *  and start the incremental rendering of the graph.
-   *  if incremental rendering is enable, else draw the
-   *  entire graph.
-   */
-  void paintGL();
+  void centerScene();
   /**
    * Change the dimension of the drawing (screen size), and enable redrawing.
-   * 
    */
-  void resizeGL(const int width, const int height);
-  
+  void changeViewport(const unsigned x, const unsigned y, const unsigned int width, const unsigned int height);
   /**
    * Draw a part of the graph, the number of elements displayed
    * is automatically computed by analysing the time used to draw
-   * the previous slice of data.
+   * the previous slice of data. If all the slice have been drawn
+   * return false;
    */
-  void drawGraph();
-
+  bool drawPart();
   /**
-   * Repaint the entire graph.
+   * Draw the entire graph.
    */
-  void redraw();
-  
+  void draw();
   /**
    * copy current values into given parameters (names are corresponding)
    */
   void getWinParameters(int *winX, int *winY, int *winW, int *winH, GLint *vp[4]);
-
   //==============================================================================
   // Data centralization in order to optimize memory using
   //==============================================================================
@@ -183,20 +119,17 @@ public:
    * Desactivate texturing
    */
   void desactivateTexture();
-
   //==============================================================================
   // Rendering parameters
   //==============================================================================
-
   /** return a Camera object which desribes the 
       camera used for he rendering
   */
   Camera getCamera() const;
-
-  /** set the camera parameter for the rendering
+  /** 
+   * set the camera parameter for the rendering
    */
   void setCamera(const Camera &cam);
-
   /** return the background color
    * \sa setBackgroundColor
    */
@@ -205,7 +138,10 @@ public:
    * \sa getBackgroundColor
    */
   void setBackgroundColor(const int r,const int g, const int b);
- 
+   /** set the background color, RGB colorspace.
+   * \sa getBackgroundColor
+   */
+  void setBackgroundColor(const Color &);
   /** activate or deactivate displaying of arrows along the graph's edges.
    * \sa isViewArrow
    */
@@ -214,7 +150,6 @@ public:
    * \sa setViewArrow
    */
   bool isViewArrow()const;
-  
   /** activate or deactivate displaying of labels on nodes and edges.
    *  \sa isViewLabel
    */
@@ -223,7 +158,6 @@ public:
    *  \sa setViewLabel
    */
   bool isViewLabel() const;
-  
   /** activate or deactivate interpolation of nodes colors along edge
    *  \sa isEdgeColorInterpolate
    */
@@ -232,7 +166,6 @@ public:
    * \sa setEdgeColorInterpolate
    */
   bool isEdgeColorInterpolate() const;
-  
   /** return the type of fonts used in the renderer(0=3D,1=bitmap,2=texture)
    *  \sa setFontsType
    */
@@ -241,7 +174,6 @@ public:
    * \sa fontsType
    */
   void setFontsType(unsigned int type);
-  
   /** if true activate the Orthogonal projection, else perspective is used.
    * \sa isViewOrtho
    */
@@ -250,22 +182,19 @@ public:
    *  \sa isViewOrtho
    */
   bool isViewOrtho() const;
-  
   /** if true glgraph use the incremental rendering else display all elements in one pass
    *  \sa isIncrementalRendering
    */
   void setIncrementalRendering(const bool state);
-
   /** return the incremental rendering state
    *  \sa setIncrementalRendering
    */
   bool isIncrementalRendering() const;
-
-  ///
   void setViewKey(const bool state);
-  ///
   bool isViewKey() const;
-  
+  void setDisplayEdges(const bool state);
+
+  bool isDisplayEdges() const;
   /** activate Strahler drawing mode. The graph is then drawn in Strahler order
    *  \sa isViewStrahler
    */
@@ -274,7 +203,6 @@ public:
    *  \sa isViewStrahler
    */
   bool isViewStrahler() const;
-  
   /** use 3D displaying of edges instead of 2D lines on ALL edges
    * \sa isEdged3D
    */
@@ -283,7 +211,6 @@ public:
    * \sa setEdge3D
    */
   bool isEdged3D() const;
-
   /** get current translation applied to the scene
    * \return current tranlation of the scene
    * \sa setSceneTranslation, setTranslation
@@ -302,23 +229,29 @@ public:
    *  \sa getSceneRotation, setRotation
    */
   void setSceneRotation(const Coord &rotation);
-
-
+  /** 
+   * Get the size of the border that is added to any label when
+   * using bitmap fonts.
+   */
+  unsigned int getLabelsBorder() const;
+  /** 
+   * Get the size of the border that is added to any label when
+   * using bitmap fonts. Setting this parameter to a high value
+   * enables de reduce the label density in the final drawing.
+   * Default value is set to 2 which enables readable labels.
+   */
+  void setLabelsBorder(const unsigned int);
   //=======================================================================
   // Navigation functions: GlGraphNavigate.cpp
   //=======================================================================
-
-
   /** set translation to apply to the scene
    * \sa getSceneTranslation, setSceneTranslation
    */
   void translateCamera(const int x, const int y, const int z);
-  
   /** set rotation to apply to the scene
    *  \sa getSceneRotation, setSceneRotation
    */
   void rotateScene(const int rotx, const int roty, const int rotz);
-
   /** zoom on the center of the screen
    *  \param step positive: zoom in, negative: zoom out
    */
@@ -330,8 +263,6 @@ public:
    *  \sa zoom
    */
   void zoomXY(const int step, const int x, const int y);
- 
- 
   //=======================================================================
   //Selection of elements on the screen
   //=======================================================================
@@ -343,15 +274,13 @@ public:
    *  \param sEdge filled by the method with the edges found in the region
    */
   void doSelect(const int x, const int y, const int width, const int height, std::set<node> &sNode, std::set<edge> &sEdge);
-  
-  /** \brief select a node or edge at a point
+   /** \brief select a node or edge at a point
    *
    *  select either a node or edge at point (x,y)
    *  \param type tells what has been found: NODE, EDGE
    *  \return true if something has been found, false otherwise
    */
-  bool doSelect(const int x, const int y, Tulip::AtomType &type, node &, edge &);
-  
+  bool doSelect(const int x, const int y, tlp::ElementType &type, node &, edge &);
   /** \brief select nodes in a region of the screen
    *
    *  select all nodes lying in the area of the screen of given width and height,
@@ -362,7 +291,6 @@ public:
           doEdgeSelect(const int, const int, const int, const int, set<edge>&);
    */
   bool doNodeSelect(const int x, const int y, const int w, const int h, std::set<node> &sNode);
-  
   /** \brief select nodes in a region of the screen
    *
    *  select all edges lying in the area of the screen of given width and height,
@@ -373,129 +301,127 @@ public:
           doNodeSelect(const int, const int, const int, const int, set<node>&);      
    */
   bool doEdgeSelect(const int x, const int y, const int w, const int h, std::set<edge> &sEdge);
-  
   /** select nodes at a given point, ordered from the closest to the farthest
    *  \param selected the nodes found
    *  \return true if at least one node has been found
    */
   bool doNodeSelect(const int x, const int y, std::vector<node> &selected);
-  
   /** select edges at a given point, ordered from the closest to the farthest
    *  \param selected the edges found
    *  \return true if at least one edge has been found
    */
   bool doEdgeSelect(const int x, const int y, std::vector<edge> &selected);
-
   //=======================================================================
   //Tools
   //=======================================================================
   //FIXME: mode outputEPS outside of GlGraph
   void outputEPS(int size, int doSort, const char *filename);
-  
-  void changeCoord(double& x, double& y, double& z);
-  
-  /** wait drawing of the graph and take a snapshot
+  /**
+   * Compute coordinate from the 2D screen space to the 
+   * 3D space.
+   */
+  void screenTo3DWorld(double& x, double& y, double& z);
+  /** 
+   *  Take a snapshot of the Open GL windows
    *  \return an array of dimension width*height*3 char (8bits per color RGB).
    *          The pointer has to be freed after (with free, not delete)
    **/
   unsigned char *getImage(int &width, int &height);
-
   //=======================================
-  //contle de la fentre openGl
+  // OpenGl Window
   //=======================================
+  /**
+   * Compute camera position in order to see the graph
+   * in the center of the scene
+   */
   void goodScale();
-
   //=========================================
   //Operation on graph's structure
   //=========================================
-  //  void del(const GLint x, const GLint y);
-
-  /** Change current graph being viewed
+  /** Change the graph being viewed
    *  \param a pointer to the graph to view
    *  \sa getSuperGraph
    */
   void setSuperGraph(SuperGraph *supergraph);
-  
-  /** get current graph being viewed
+  /** get the graph being viewed
    *  \return a pointer to the current graph
    *  \sa setSuperGraph
    */
   SuperGraph* getSuperGraph() const;
 
-  //  void delSelection();
-
-  SuperGraph     *_superGraph;
   static TemplateFactory<GlyphFactory,Glyph,GlyphContext *> glyphFactory;
+  static std::string glyphName(int id);
+  static int glyphId(std::string name);
+  static void loadPlugins(PluginLoader *plug=0);
+
+private:
+  static stdext::hash_map<int,std::string>  idToName;
+  static stdext::hash_map<std::string, int> nameToId;
 
 protected:
+  void addNode (SuperGraph *, const node);
+  void addEdge (SuperGraph *, const edge);
+  void delNode (SuperGraph *, const node);
+  void delEdge (SuperGraph *, const edge);
+  void destroy (SuperGraph *);
+  float projectSize(const Coord&, const Size&);
+  void drawPixmapFont(const std::string &str, const Coord &position, bool selected);
   void drawEdge(const Coord &startNode, const Coord &finalNode,
                 const Coord &startPoint,const LineType::RealType &bends, const Coord &endPoint,
 		const Color &startColor, const Color &endColor, const Size &size, int shape, const bool selected=false);
   void drawEdge(edge ite);
   unsigned int drawEdges(unsigned int , Iterator<edge> *);
-  unsigned int drawEdges(unsigned int , std::list<edge>::iterator &) _DEPRECATED;
   void drawNode(node itv,unsigned int depth);
   unsigned int drawNodes(unsigned int , Iterator<node> *);
-  unsigned int drawNodes(unsigned int , std::list<node>::iterator &) _DEPRECATED;
+  unsigned int drawLabels(unsigned int , Iterator<node> *, bool);
+  void drawLabel(node itn);
+  void drawEdgeLabel(edge e);
+  unsigned int drawEdgeLabels(unsigned int number, Iterator<edge> *itE, bool mode);
   void drawFanNode(node n) ;
   unsigned int drawFanNodes(unsigned int , Iterator<node> *);
-  void drawMetaNode(node n,unsigned int depth);
+  void drawMetaNode(node n,unsigned int depth, bool label = false);
   void DrawBitmapString(void *, const char *);
   void DrawStrokeString(void *font, const char *string);
   void makeArrowMatrix(GLfloat *, const Coord , const Coord , GLfloat, GLfloat, GLfloat);
   void initProxies();
-
-
-  
-  ///
+  void deleteIterators();
+  void initIterators();
   void initDoSelect(const GLint x, const GLint y, GLint w, GLint h);
-  ///
   void endSelect();
-  ///
   void makeNodeSelect(const int);
-  ///
   void makeEdgeSelect(const int);
-  ///
-  ///void addSelection(const GLint x, const GLint y);
-  ///
-  ///  void initAndSelect(const GLint x, const GLint y);
-  ///
-  /// void selectItem(const GLint x, const GLint y);
-
   void initProjection(bool reset=true);
   void initModelView();
   void initLights();
   void initGlParameter();
-
-
-
-  //  void buildColor();
   void buildOrderedList();
+  void buildDisplayLists();
+  void deleteDisplayLists();
+  void transparentSphere();
+  void cubeWire();
+  void solidCone();
+
 
-  GLuint makeSelectionObject();
-  GLuint makeCubeWireObject();
-  GLuint makeConeObject();
 private:
-  PropertyProxyContainer *graphProperties;
+  GlGraphStrategy *strategy;
+  SuperGraph     *_superGraph;
   Color  backgroundColor;
+
   bool _viewArrow, _viewLabel, _viewKey, _viewStrahler;
   bool _viewAutoScale, _incrementalRendering, _edgeColorInterpolate, _edge3D;
   unsigned int _viewOrtho;
   unsigned int _FontsType;
-
+  bool _displayEdges;
   
-  int winH;
-  int winW;
-
-  STL_EXT_NS::hash_map<int, Glyph *, STL_EXT_NS::hash<int> >  glyphTable;
+  //  stdext::hash_map<int, Glyph *, stdext::hash<int> >  glyphTable;
 
 
-  STL_EXT_NS::hash_map<std::string, GLuint > texturesMap; //FIXME: make it static?
+  stdext::hash_map<std::string, GLuint > texturesMap; //FIXME: make it static?
   
-  //display list holding drawing of metaGraph - currently a wire cube
-  GLuint	 metaGraphDL;
-  //display list holding selection of nodes - currently a transparent pink sphere
-  GLuint	 selectionDL;
+
+  GLint viewportArray[4];
+  GLdouble modelviewMatrix[16];
+  GLdouble projectionMatrix[16];
 
 
   //FIXME: made public to allow glyphs to access those proxy
@@ -510,48 +436,63 @@ public:
   StringProxy	 *elementTexture;
 
 private:
-  //a factoriser
+
+  //we never have to get a copy of that GlGraph.
+  //GlGraph objects should be only passed by reference or pointer
+  GlGraph(const GlGraph &);
+
+
+private:
+
   GLint vp[4]; //->getGetIntegerv(GL_VIEWPORT)
   GLuint (*selectBuf)[4];
-  GLuint objectGraph,objectCube,objectCone;
 
+  //predefined display list
+  GLuint metaGraphDL;
+  GLuint selectionDL;
+  GLuint arrowDL;
+  //glyphs
+  MutableContainer<Glyph *> glyphs;
   //Scene information
   Coord sceneTranslation; // Scene translation
   Coord sceneRotation; // Rotation of the scene
-
-
-
   //Camera information
   Coord cameraEyes,cameraCenter,cameraUp;
   double cameraZoomFactor;
   GLfloat distCam;   //distance for camera translation
-
-  int winX,winY; 
-  std::map<double,double> colorMap;
-  double colorMapMin,colorMapMax;
+  //viewport position and size
+  unsigned int winX, winY; 
+  unsigned int winH, winW;
 
   //+++
   Iterator<node>* drawNodesIterator;
+  Iterator<node>* drawLabelsIterator;
+  Iterator<node>* drawSelectedLabelsIterator;
   Iterator<edge>* drawEdgesIterator;
-  std::list<node>::iterator drawNodesIteratorStl;
-  std::list<edge>::iterator drawEdgesIteratorStl;
+  Iterator<edge>* drawEdgeLabelsIterator;
+  Iterator<edge>* drawEdgeSelectedLabelsIterator;
+
   std::list<node> orderedNode;
   std::list<edge> orderedEdge;
-  double nodeSizex,nodeSizey;
 
   //Incremental rendering parameters
   int maxNumberOfNodeToDraw;
   int maxNumberOfEdgeToDraw;
 
+  //
+  MutableContainer<unsigned int> nbElementsFrame;
+  unsigned int currentFrame;
+  unsigned drawState;
+  unsigned int labelsBorder;
+
   //Occlusion testing
-  ListRectangleInt2D occlusionTest;
-  char bitmapMask[500000];
+  OcclusionTest occlusionTest;
 };
 
 
-template<typename T> struct stlListIterator:public Iterator<T> {
-  typename std::list<T>::iterator &it,itEnd;
-  stlListIterator(typename std::list<T>::iterator &startIt, typename std::list<T>::iterator endIt):it(startIt),itEnd(endIt){}
+template<typename T, typename IT> struct stlListIterator:public Iterator<T> {
+  IT it,itEnd;
+  stlListIterator(const IT &startIt, const IT &endIt):it(startIt),itEnd(endIt){}
   T next(){T tmp=*it;++it;return tmp;}
   bool hasNext(){return (itEnd!=it);}
 };
