@@ -12,9 +12,6 @@ public:
   virtual void MakeCurrent()=0;
   virtual void UpdateGL()=0;
 
-  //GL stuff
-  virtual void setDoubleBuffering(bool)=0;
-  
   //timer methods
   virtual bool timerIsActive()=0;
   virtual int timerStart(int msec, bool sshot=false)=0;
@@ -22,11 +19,14 @@ public:
 
   //
   virtual void mPaint(GlGraph *)=0;
+  /*
   virtual void outputSetText(const std::string&)=0;
   virtual const std::string outputGetText()=0;
+  */
   //
   //GlGraph will call this if it can't handle Observable
-  virtual void update(std::set<Observable *>::iterator itb)=0;
+  //  virtual void update(std::set<Observable *>::iterator itb)=0;
+
 
   bool toUpdate;
 };
