@@ -23,12 +23,10 @@ public:
   void mReleaseEvent(GlGraphWidget *,QMouseEvent *);
   void mMoveEvent(GlGraphWidget *,QMouseEvent *);
   void mPaint(GlGraphWidget *);
-  void keyPressEvent (GlGraphWidget *, QKeyEvent *) {}
-  void keyReleaseEvent(GlGraphWidget *, QKeyEvent *);
-  void wheelEvent(GlGraphWidget *, QWheelEvent *) {}
+  void keyPressEvent (GlGraphWidget *, QKeyEvent *){}
+  void keyReleaseEvent(GlGraphWidget *, QKeyEvent *){}
+  void wheelEvent(GlGraphWidget *, QWheelEvent *){}
 
-private:
-  void cancelZoomOp(GlGraphWidget *);
 };
 
 #endif //MOUSEZOOMBOX_H
