@@ -17,7 +17,8 @@
 class PropertyContext;
 class ColorsProxy;
 
-
+/** \addtogroup plugins */ 
+/*@{*/
 /// Interface for colors plug-ins
 class Colors:public Property< ColorType , ColorType >
 { 
@@ -27,11 +28,11 @@ public:
   ColorsProxy *colorsProxy;
 protected:
   ///
-  Colors (PropertyContext  *context);
+  Colors (const PropertyContext & context);
   ///
   virtual ~Colors(){}
 };
-
+/*@}*/
 #endif
 
 
