@@ -17,8 +17,7 @@
 
 class IdManagerIterator;
 
-class IdManager
-{
+class IdManager {
   friend std::ostream& operator<<(std::ostream &,const IdManager &);
   friend class IdManagerIterator;
 
@@ -45,23 +44,18 @@ public:
   Iterator<unsigned int>* getUsedId() const;
 };
 
-
-
-
-class IdManagerIterator:public Iterator<unsigned int> 
-{
-private:
-  unsigned int index;
-  std::set<unsigned int>::const_iterator it;
-  const IdManager &idMan;
+class IdManagerIterator:public Iterator<unsigned int>  {
 public:
   IdManagerIterator(const IdManager &idMan);
   ~IdManagerIterator();
   unsigned  int  next();
   bool hasNext();
+private:
+  unsigned int index;
+  std::set<unsigned int>::const_iterator it;
+  const IdManager &idMan;
 };
 
-
 std::ostream& operator<<(std::ostream &,const IdManager &);
 
 #endif
