@@ -18,6 +18,8 @@
 class PropertyContext;
 class IntProxy;
 
+/** \addtogroup plugins */ 
+/*@{*/
 
 /// Interface for int plug-ins
 class Int:public Property<IntType , IntType>
@@ -30,11 +32,11 @@ public:
   IntProxy *intProxy;
 protected:
   ///
-  Int (PropertyContext  *context);
+  Int (const PropertyContext  &context);
   ///
   virtual ~Int(){}
 };
-
+/*@}*/
 #endif
 
 
