@@ -9,53 +9,30 @@
 class Ggraph;
 class PropertyContext;
 
-///
-class IntProxy:public PropertyProxy<IntType,IntType>
-{ 
-  ///
+/** \addtogroup properties */ 
+/*@{*/
+class IntProxy:public PropertyProxy<IntType,IntType>{ 
+
   friend class Int;
 
-public:
-  static TemplateFactory<IntFactory,Int,PropertyContext *> factory;
+public :
+  IntProxy (SuperGraph *);
+  ~IntProxy();
+  IntType::RealType  getNodeMin();
+  IntType::RealType  getNodeMax();
+  IntType::RealType  getEdgeMin();
+  IntType::RealType  getEdgeMax();
+  PProxy* clonePrototype(SuperGraph *, std::string );
+  void copy( const node, const node, PProxy * );
+  void copy( const edge, const edge, PProxy * );
+  void reset_handler();
+  void recompute_handler();
+  void clone_handler(PropertyProxy<IntType,IntType> &);
 
 private:
-  ///
   int maxN,minN,maxE,minE;
-  ///
   bool minMaxOk;
-  ///
   void computeMinMax();
-  ///
-  Int *currentInt;
-
-public :
-  ///
-  IntProxy (PropertyContext *context);
-  ///
-  ~IntProxy();
-  ///
-  bool select(std::string , std::string &);
-  
-  //==========================================
-  //Fonction apportant des informations 
-  //supplmentaire sur la mtrique
-  ///
-  IntType::RealType  getNodeMin();
-  ///
-  IntType::RealType  getNodeMax();
-  ///
-  IntType::RealType  getEdgeMin();
-  ///
-  IntType::RealType  getEdgeMax();
-  ///
-  void reset_handler();
-  ///
-  void recompute_handler();
-  ///
-  void clone_handler(PropertyProxy<IntType,IntType> &);
 };
-
-
-
+/*@}*/
 #endif
-
