@@ -17,23 +17,27 @@
 class PropertyContext;
 class LayoutProxy;
 
-
+/**
+ * \defgroup plugins
+ */ 
+/*@{*/
 ///Interface for layout plug-ins
-class Layout:public Property<PointType , LineType>
-{
+class Layout:public Property<PointType , LineType> {
   ///
   friend class LayoutProxy;
 public:
-  /** This layout proxy is the one associated to the plug-ins,
-      The data should be store in it*/
+  /** 
+   * This layout proxy is the one associated to the plug-ins,
+   * The data should be store in it
+   */
   LayoutProxy *layoutProxy;
 protected: 
   ///
-  Layout (PropertyContext *context);
+  Layout (const PropertyContext &context);
   ///
   virtual ~Layout();
 };
-
+/*@}*/
 
 
 #endif
