@@ -8,33 +8,22 @@
 
 class PropertyContext;
 
-///
-class MetaGraphProxy:public PropertyProxy<MetaGraphType,MetaGraphType>
-{ 
-  ///
+/** \addtogroup properties */ 
+/*@{*/
+class MetaGraphProxy:public PropertyProxy<MetaGraphType,MetaGraphType> { 
+
   friend class MetaGraph;
 
-public:
-  static TemplateFactory<MetaGraphFactory,MetaGraph,PropertyContext *> factory;
-
-private:
-  ///
-  MetaGraph *currentMetaGraph;
-
 public :
-  ///
-  MetaGraphProxy (PropertyContext *context);
-  ///
+  MetaGraphProxy (SuperGraph *);
   ~MetaGraphProxy();
-  ///
-  bool select(std::string , std::string &);
-  ///
+  PProxy* clonePrototype(SuperGraph *, std::string );
+  void copy( const node, const node, PProxy * );
+  void copy( const edge, const edge, PProxy * );
   void reset_handler();
-  ///
   void recompute_handler();
-  ///
   void clone_handler(PropertyProxy<MetaGraphType,MetaGraphType> &);
 };
-
+/*@}*/
 #endif
 
