@@ -17,11 +17,10 @@
 
 class PropertyContext;
 class MetricProxy;
-
-
+/** \addtogroup plugins */ 
+/*@{*/
 /// Interface for metric plug-ins
-class Metric:public Property<DoubleType , DoubleType>
-{ 
+class Metric:public Property<DoubleType , DoubleType> { 
   ///
   friend class MetricProxy;
 public:
@@ -30,10 +29,11 @@ public:
   MetricProxy *metricProxy;
 protected:
   ///
-  Metric (PropertyContext  *context);
+  Metric (const PropertyContext  &context);
   ///
   virtual ~Metric(){}
 };
+/*@}*/
 
 #endif
 
