@@ -18,6 +18,11 @@
 class PropertyContext;
 class SelectionProxy;
 
+/**
+ * \defgroup plugins
+ */ 
+/*@{*/
+
 /// Interface for selection plug-ins
 class Selection:public Property<BooleanType , BooleanType>
 { 
@@ -30,11 +35,11 @@ public:
 
 protected:
   ///
-  Selection (PropertyContext *);
+  Selection (const PropertyContext &);
   ///
   virtual ~Selection(){}
 };
-
+/*@*/
 #endif
 
 
