@@ -3,7 +3,7 @@
 #define TULIP_SIZE_H
 #include <tulip/Vector.h>
 ///
-class Size : public tlp::geo::Vector<float,3> {
+class Size : public tlp::Vector<float,3> {
 public:
   inline Size(const float width=0,const float height=0,const float depth=0);
   ///
