@@ -17,6 +17,10 @@
 class PropertyContext;
 class SizesProxy;
 
+/**
+ * \defgroup plugins
+ */ 
+/*@{*/
 /// Interface for sizes plug-ins
 class Sizes:public Property< SizeType , SizeType >
 { 
@@ -26,11 +30,11 @@ public:
   SizesProxy *sizesProxy;
 protected:
   ///
-  Sizes (PropertyContext  *context);
+  Sizes (const PropertyContext  &context);
   ///
   virtual ~Sizes(){}
 };
-
+/*@}*/
 #endif
 
 
