@@ -7,39 +7,25 @@
 #include "TemplateFactory.h"
 
 class PropertyContext;
+/**
+ * \defgroup properties
+ */ 
+/*@{*/
+class SizesProxy:public PropertyProxy<SizeType,SizeType> { 
 
-///
-class SizesProxy:public PropertyProxy<SizeType,SizeType>
-{ 
-  ///
   friend class Sizes;
 
-public:
-  static TemplateFactory<SizesFactory,Sizes,PropertyContext *> factory;
-
-private:
-  ///
-  Sizes *currentSizes;
-  //  Coord max,min;
-  STL_EXT_NS::hash_map<int,Size> max,min;
-  ///
-  STL_EXT_NS::hash_map<int,bool> minMaxOk;
-  ///
-  void computeMinMax(SuperGraph * sg=NULL);
 public :
-  ///
-  SizesProxy (PropertyContext *context);
-  ///
+  SizesProxy (SuperGraph *);
   ~SizesProxy();
-  ///
-  bool select(std::string , std::string &);
-  ///
   void reset_handler();
-  ///
   void recompute_handler();
-  ///
   Size getMax(SuperGraph *sg=0);
   Size getMin(SuperGraph *sg=0);
+  PProxy* clonePrototype(SuperGraph *, std::string );
+  void copy( const node, const node, PProxy * );
+  void copy( const edge, const edge, PProxy * );
+
 protected:
   void resetMinMax();
   virtual void setNodeValue_handler(const node n);
@@ -47,7 +33,11 @@ protected:
   virtual void setAllNodeValue_handler();
   virtual void setAllEdgeValue_handler();
 
+private:
+  stdext::hash_map<int,Size> max,min;
+  stdext::hash_map<int,bool> minMaxOk;
+  void computeMinMax(SuperGraph * sg=NULL);
 };
-
+/*@}*/
 #endif
 
