@@ -19,6 +19,9 @@
 class PropertyContext;
 class StringProxy;
 
+/** \addtogroup plugins */ 
+/*@{*/
+
 /// Interface for String plug-ins
 class String:public Property<StringType , StringType>
 { 
@@ -31,11 +34,12 @@ public:
 
 protected:
   ///
-  String (PropertyContext *context);
+  String (const PropertyContext &context);
   ///
   virtual ~String(){}
 };
 
+/*@}*/
 #endif
 
 
