@@ -4,25 +4,29 @@
 
 #include "PluginLoader.h"
 #include "WithParameter.h"
+#include "Iterator.h"
 
-template<class ObjectFactory, class ObjectType, class Parameter> class TemplateFactory
-{
+/** \addtogroup plugins */ 
+/*@{*/
+template<class ObjectFactory, class ObjectType, class Parameter> class TemplateFactory {
 public:
   typedef void *(*func)();
-  typedef std::map< std::string , ObjectFactory * , std::less<std::string> > ObjectCreator;
-  
+  typedef std::map< std::string , ObjectFactory * > ObjectCreator;
   void *handle;
   func createObj;
+
   ObjectCreator objMap;
   std::map<std::string,StructDef> objParam;
+  std::set<std::string> objNames;
 
+  Iterator<std::string>* availablePlugins();
   bool exists(const std::string &pluginName);
   void load(std::string pluginPath,std::string type,PluginLoader *loader=0);
   bool load(std::string file);
   ObjectType *getObject(std::string name,Parameter p);
   StructDef getParam(std::string name);
 };
-
+/*@}*/
 #include "./cxx/TemplateFactory.cxx"
 #endif
 
