@@ -8,8 +8,7 @@
 #include "tulip/SuperGraph.h"
 #include "tulip/ColorsProxy.h"
 
-Colors::Colors (PropertyContext *context):Property<ColorType , ColorType>(context)
-{
-  colorsProxy=(ColorsProxy *)propertyProxy;
+Colors::Colors (const PropertyContext &context):Property<ColorType , ColorType>(context) {
+  colorsProxy=(ColorsProxy *)context.propertyProxy;
 }
 
