@@ -7,8 +7,7 @@
 #include "tulip/SuperGraph.h"
 #include "tulip/IntProxy.h"
 
-Int::Int (PropertyContext *context):Property<IntType , IntType>(context)
-{
-  intProxy=(IntProxy *)propertyProxy;
+Int::Int (const PropertyContext & context):Property<IntType , IntType>(context) {
+  intProxy=(IntProxy *)context.propertyProxy;
 }
 
