@@ -9,9 +9,8 @@
 #include "tulip/PluginContext.h"
 #include "tulip/LayoutProxy.h"
 
-Layout::Layout (PropertyContext *context):Property<PointType , LineType>(context)
-{
-  layoutProxy=(LayoutProxy *)propertyProxy;
+Layout::Layout (const PropertyContext & context):Property<PointType , LineType>(context) {
+  layoutProxy=(LayoutProxy *)context.propertyProxy;
 }
 
 Layout::~Layout() {}
