@@ -7,8 +7,7 @@
 #include "tulip/SuperGraph.h"
 #include "tulip/MetricProxy.h"
 
-Metric::Metric (PropertyContext *context):Property<DoubleType , DoubleType>(context)
-{
-  metricProxy=(MetricProxy *)propertyProxy;
+Metric::Metric (const PropertyContext &context):Property<DoubleType , DoubleType>(context) {
+  metricProxy=(MetricProxy *)context.propertyProxy;
 }
 
