@@ -3,7 +3,7 @@
 #endif
 
 #include <cassert>
-
+#include <iostream>
 #include "tulip/Observable.h"
 
 
@@ -12,9 +12,14 @@ using namespace std;
 int Observable::holdCounter=0;
 
 ObserverMap Observable::holdMap;
+static bool unholdLock=false;
 
 void Observable::notifyObservers()
 {
+  if (unholdLock) {
+    cerr << "Cannot notifyObservers during unholdings" << endl;
+    return;
+  }
   //  cerr << "Observable::notifyObservers" << endl;
   list<Observer*>::iterator itlObs;
   assert(holdCounter>=0);
@@ -24,30 +29,36 @@ void Observable::notifyObservers()
   else
     {
       set<Observable *> tmpSet;
+      std::list<Observer*> tmpList(observersList);
       tmpSet.insert(this);
-      for (itlObs=observersList.begin();itlObs!=observersList.end();++itlObs)
+      for (itlObs=tmpList.begin();itlObs!=tmpList.end();++itlObs)
 	(*itlObs)->update(tmpSet.begin(),tmpSet.end());
     }
 }
 
 void Observable::holdObservers()
 {
+  //  cerr << __PRETTY_FUNCTION__ << " :=> " << holdCounter << endl;
   assert(holdCounter>=0);
   holdCounter++;
 }
 
 void Observable::unholdObservers()
 {
-  holdCounter--;
   assert(holdCounter>=0);
- 
-  if (holdCounter==0)
-    {
-      ObserverMap::iterator itMObs;
-      for (itMObs=holdMap.begin();itMObs!=holdMap.end();++itMObs)
-	itMObs->first->update(itMObs->second.begin(),itMObs->second.end());
-      holdMap.clear();
+  //  cerr << __PRETTY_FUNCTION__ << " :=> " << holdCounter << endl;
+  holdCounter--;
+  if (unholdLock) return;
+  unholdLock=true; 
+  if (holdCounter==0) {
+    ObserverMap tmp(holdMap);
+    holdMap.clear();
+    ObserverMap::iterator itMObs;
+    for (itMObs=tmp.begin();itMObs!=tmp.end();++itMObs) {
+      itMObs->first->update(itMObs->second.begin(),itMObs->second.end());
     }
+  }
+  unholdLock=false;
 }
 
 
