@@ -7,7 +7,7 @@
 #include "tulip/SuperGraph.h"
 #include "tulip/SelectionProxy.h"
 
-Selection::Selection (PropertyContext *context):Property<BooleanType , BooleanType>(context)
-{
-  selectionProxy=(SelectionProxy *)propertyProxy;
+Selection::Selection (const PropertyContext & context):Property<BooleanType , BooleanType>(context) {
+  selectionProxy=(SelectionProxy *)context.propertyProxy;
 }
+
