@@ -8,8 +8,7 @@
 #include "tulip/SuperGraph.h"
 #include "tulip/SizesProxy.h"
 
-Sizes::Sizes (PropertyContext *context):Property<SizeType , SizeType>(context)
-{
-  sizesProxy=(SizesProxy *)propertyProxy;
+Sizes::Sizes (const PropertyContext &context):Property<SizeType , SizeType>(context) {
+  sizesProxy=(SizesProxy *)context.propertyProxy;
 }
 
