@@ -6,8 +6,7 @@
 #include "tulip/String.h"
 #include "tulip/SuperGraph.h"
 #include "tulip/StringProxy.h"
-String::String (PropertyContext *context):Property<StringType , StringType>(context)
-{
-  stringProxy=(StringProxy *)propertyProxy;
+String::String (const PropertyContext & context):Property<StringType , StringType>(context) {
+  stringProxy=(StringProxy *)context.propertyProxy;
 }
 
