@@ -3,8 +3,7 @@
 #include "ConvolutionClusteringSetupData.h"
 #include "ConvolutionClustering.h"
 
-class ConvolutionClusteringSetup : public ConvolutionClusteringSetupData
-{ 
+class ConvolutionClusteringSetup : public ConvolutionClusteringSetupData { 
     Q_OBJECT
 
 public:
