@@ -7,17 +7,19 @@
 
 #include <tulip/TulipPlugin.h>
 
-class HierarchicalClustering:public Clustering
-{ 
+/** \addtogroup clustering */
+/*@{*/
+class HierarchicalClustering:public Clustering { 
 public:
   HierarchicalClustering(ClusterContext);
   ~HierarchicalClustering();
-  bool split (MetricProxy *, std::list<node> &);
   bool run();
   bool check(std::string &);
   void reset();
-
+private :
+  bool split (MetricProxy *, std::list<node> &);
 };
+/*@}*/
 
 #endif
 
