@@ -8,8 +8,11 @@
 
 #include <tulip/TulipPlugin.h>
 
-class StrengthClustering:public Clustering
-{ 
+class MetricProxy;
+
+/** \addtogroup clustering */
+/*@{*/
+class StrengthClustering:public Clustering { 
 public:
   StrengthClustering(ClusterContext);
   ~StrengthClustering();
@@ -23,6 +26,7 @@ private:
   double s(std::set<node> &U);
   double computeMQValue(std::vector< std::set<node> > partition);
   std::vector< std::set<node> > computeNodePartition(double threshold);
+  MetricProxy * values;
 };
-
+/*@}*/
 #endif
