@@ -21,11 +21,11 @@
 #endif
 
 #include <tulip/TulipPlugin.h>
-#include <tulip/SubGraph.h>
-#include <tulip/TypeConverter.h>
 #include <tulip/MetaGraphProxy.h>
+#include <tulip/Types.h>
 #include <tulip/Coord.h>
-#include <gzstream.h>
+#include <tulip/TlpTools.h>
+#include <tulip/PropertyProxy.h>
 
 #include "TLPParser.h"
 
@@ -57,21 +57,15 @@
 
 using namespace std;
 //=================================================================================
-struct TLPGraphBuilder:public TLPTrue
-{
+struct TLPGraphBuilder:public TLPTrue {
   SuperGraph *_superGraph;
   map<int,node> nodeIndex;
   map<int,edge> edgeIndex;
   map<int,SuperGraph *> clusterIndex;
-  map<int,SubGraph *> subGraphIndex;
-
   DataSet *dataSet;
-  bool cameraFlag;
   
   TLPGraphBuilder(SuperGraph *superGraph, DataSet *dataSet): _superGraph(superGraph),
-							     dataSet(dataSet),
-							     cameraFlag(false)
-  {
+							     dataSet(dataSet) {
     clusterIndex[0]=superGraph;
   }
 
@@ -96,7 +90,6 @@ struct TLPGraphBuilder:public TLPTrue
   }
   bool setNodeValue(int nodeId, int clusterId, const string propertyType, const string propertyName, string value) {
     //cerr << "set node value ....." ;
-
     if (propertyType==METAGRAPH) {
       char *endPtr=0;
       const char *startPtr=value.c_str();
@@ -104,45 +97,30 @@ struct TLPGraphBuilder:public TLPTrue
       if (endPtr==startPtr) return false;
       if (clusterIndex.find(result)==clusterIndex.end()) return false;
       if (result==0) 
-	getLocalProxy<MetaGraphProxy>(clusterIndex[clusterId],propertyName)->setNodeValue(nodeIndex[nodeId],0);
+	clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setNodeValue(nodeIndex[nodeId],0);
       else
-	getLocalProxy<MetaGraphProxy>(clusterIndex[clusterId],propertyName)->setNodeValue(nodeIndex[nodeId],clusterIndex[result]);
+	clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setNodeValue(nodeIndex[nodeId],clusterIndex[result]);
       return true;
     }
     if (propertyType==METRIC) 
-      return stringToNodeProperty(getLocalProxy<MetricProxy>(clusterIndex[clusterId],propertyName), 
-				  nodeIndex[nodeId],
-				  value);
+      return clusterIndex[clusterId]->getLocalProperty<MetricProxy>(propertyName)->setNodeStringValue( nodeIndex[nodeId], value );
     if (propertyType==LAYOUT) 
-      return stringToNodeProperty(getLocalProxy<LayoutProxy>(clusterIndex[clusterId],propertyName), 
-				  nodeIndex[nodeId],
-				  value);
+      return clusterIndex[clusterId]->getLocalProperty<LayoutProxy>(propertyName)->setNodeStringValue( nodeIndex[nodeId], value );
     if (propertyType==SIZE) 
-      return stringToNodeProperty(getLocalProxy<SizesProxy>(clusterIndex[clusterId],propertyName), 
-				  nodeIndex[nodeId],
-				  value);
+      return clusterIndex[clusterId]->getLocalProperty<SizesProxy>(propertyName)->setNodeStringValue( nodeIndex[nodeId], value );
     if (propertyType==COLOR) 
-      return stringToNodeProperty(getLocalProxy<ColorsProxy>(clusterIndex[clusterId],propertyName),
-				  nodeIndex[nodeId],
-				  value);
+      return clusterIndex[clusterId]->getLocalProperty<ColorsProxy>(propertyName)->setNodeStringValue( nodeIndex[nodeId], value );
     if (propertyType==INT) 
-      return stringToNodeProperty(getLocalProxy<IntProxy>(clusterIndex[clusterId],propertyName), 
-				  nodeIndex[nodeId],
-				  value);
+      return clusterIndex[clusterId]->getLocalProperty<IntProxy>(propertyName)->setNodeStringValue( nodeIndex[nodeId], value );
     if (propertyType==BOOL) 
-      return stringToNodeProperty(getLocalProxy<SelectionProxy>(clusterIndex[clusterId],propertyName), 
-				  nodeIndex[nodeId],
-				  value);
+      return clusterIndex[clusterId]->getLocalProperty<SelectionProxy>(propertyName)->setNodeStringValue( nodeIndex[nodeId], value );
     if (propertyType==STRING) 
-      return stringToNodeProperty(getLocalProxy<StringProxy>(clusterIndex[clusterId],propertyName), 
-				  nodeIndex[nodeId],
-				  value);
+      return clusterIndex[clusterId]->getLocalProperty<StringProxy>(propertyName)->setNodeStringValue( nodeIndex[nodeId], value );
     return false;
     //cer << "..ok" << endl;
   }
   
-  bool setEdgeValue(int edgeId, int clusterId, const string &propertyType, const string &propertyName, string value)
-  {
+  bool setEdgeValue(int edgeId, int clusterId, const string &propertyType, const string &propertyName, string value) {
     //cerr << "setEdgeValue...." << "edge:" << edgeId << " cluster " << clusterId << " " << propertyName << " " << propertyType << " value=\""<< value<<"\"  ";
     bool result=false;
 
@@ -153,77 +131,61 @@ struct TLPGraphBuilder:public TLPTrue
       if (endPtr==startPtr) return false;
       if (clusterIndex.find(result)==clusterIndex.end()) return false;
       if (result==0) 
-	getLocalProxy<MetaGraphProxy>(clusterIndex[clusterId],propertyName)->setEdgeValue(edgeIndex[edgeId],0);
+	clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setEdgeValue(edgeIndex[edgeId],0);
       else
-	getLocalProxy<MetaGraphProxy>(clusterIndex[clusterId],propertyName)->setEdgeValue(edgeIndex[edgeId],clusterIndex[result]);
+	clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setEdgeValue(edgeIndex[edgeId],clusterIndex[result]);
       return true;
     }
     if (propertyType==METRIC) 
-      result= stringToEdgeProperty( getLocalProxy<MetricProxy>(clusterIndex[clusterId],propertyName), 
-				    edgeIndex[edgeId],
-				    value);
+      result= clusterIndex[clusterId]->getLocalProperty<MetricProxy>(propertyName)->setEdgeStringValue( edgeIndex[edgeId], value );
     if (propertyType==LAYOUT) 
-      result= stringToEdgeProperty(getLocalProxy<LayoutProxy>(clusterIndex[clusterId],propertyName), 
-				   edgeIndex[edgeId],
-				   value);
+      result= clusterIndex[clusterId]->getLocalProperty<LayoutProxy>(propertyName)->setEdgeStringValue( edgeIndex[edgeId], value );
     if (propertyType==SIZE) 
-      result= stringToEdgeProperty(getLocalProxy<SizesProxy>(clusterIndex[clusterId],propertyName), 
-				   edgeIndex[edgeId],
-				   value);
+      result= clusterIndex[clusterId]->getLocalProperty<SizesProxy>(propertyName)->setEdgeStringValue( edgeIndex[edgeId], value );
     if (propertyType==COLOR) 
-      result= stringToEdgeProperty(getLocalProxy<ColorsProxy>(clusterIndex[clusterId],propertyName), 
-				   edgeIndex[edgeId],
-				   value);
+      result= clusterIndex[clusterId]->getLocalProperty<ColorsProxy>(propertyName)->setEdgeStringValue( edgeIndex[edgeId], value );
     if (propertyType==INT) 
-      result= stringToEdgeProperty(getLocalProxy<IntProxy>(clusterIndex[clusterId],propertyName), 
-				   edgeIndex[edgeId],
-				   value);
+      result= clusterIndex[clusterId]->getLocalProperty<IntProxy>(propertyName)->setEdgeStringValue( edgeIndex[edgeId], value );
     if (propertyType==BOOL) 
-      result= stringToEdgeProperty(getLocalProxy<SelectionProxy>(clusterIndex[clusterId],propertyName), 
-				   edgeIndex[edgeId],
-				   value);
+      result= clusterIndex[clusterId]->getLocalProperty<SelectionProxy>(propertyName)->setEdgeStringValue( edgeIndex[edgeId], value );
     if (propertyType==STRING) 
-      result= stringToEdgeProperty(getLocalProxy<StringProxy>(clusterIndex[clusterId],propertyName), 
-				   edgeIndex[edgeId],
-				   value);
+      result= clusterIndex[clusterId]->getLocalProperty<StringProxy>(propertyName)->setEdgeStringValue( edgeIndex[edgeId], value );
     //cer<< "..ok result=" << result<< endl;
     return result;
   }
 
-  bool setAllNodeValue(int clusterId, const string propertyType, const string propertyName, string value)
-  {
+  bool setAllNodeValue(int clusterId, const string propertyType, const string propertyName, string value) {
     //cerr << "set all node value ....." ;
     if (propertyType==METAGRAPH) {
       char *endPtr=0;
       const char *startPtr=value.c_str();
       int result=strtol(startPtr,&endPtr,10);
-      if (endPtr==startPtr) return false;
+      if (endPtr==startPtr) result =0; //return false;
       if (clusterIndex.find(result)==clusterIndex.end()) return false;
       if (result==0) 
-	getLocalProxy<MetaGraphProxy>(clusterIndex[clusterId],propertyName)->setAllNodeValue(0);
+	clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setAllNodeValue(0);
       else
-	getLocalProxy<MetaGraphProxy>(clusterIndex[clusterId],propertyName)->setAllNodeValue(clusterIndex[result]);
+	clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setAllNodeValue(clusterIndex[result]);
       return true;
     }
     if (propertyType==METRIC) 
-      return stringToAllNodeProperty(getLocalProxy<MetricProxy>(clusterIndex[clusterId],propertyName), value);
+      return clusterIndex[clusterId]->getLocalProperty<MetricProxy>(propertyName)->setAllNodeStringValue( value );
     if (propertyType==LAYOUT) 
-      return stringToAllNodeProperty(getLocalProxy<LayoutProxy>(clusterIndex[clusterId],propertyName), value);
+      return clusterIndex[clusterId]->getLocalProperty<LayoutProxy>(propertyName)->setAllNodeStringValue( value );
     if (propertyType==SIZE) 
-      return stringToAllNodeProperty(getLocalProxy<SizesProxy>(clusterIndex[clusterId],propertyName), value);
+      return clusterIndex[clusterId]->getLocalProperty<SizesProxy>(propertyName)->setAllNodeStringValue( value );
     if (propertyType==COLOR) 
-      return stringToAllNodeProperty(getLocalProxy<ColorsProxy>(clusterIndex[clusterId],propertyName), value);
+      return clusterIndex[clusterId]->getLocalProperty<ColorsProxy>(propertyName)->setAllNodeStringValue( value );
     if (propertyType==INT) 
-      return stringToAllNodeProperty(getLocalProxy<IntProxy>(clusterIndex[clusterId],propertyName), value);
+      return clusterIndex[clusterId]->getLocalProperty<IntProxy>(propertyName)->setAllNodeStringValue( value );
     if (propertyType==BOOL) 
-      return stringToAllNodeProperty(getLocalProxy<SelectionProxy>(clusterIndex[clusterId],propertyName), value);
+      return clusterIndex[clusterId]->getLocalProperty<SelectionProxy>(propertyName)->setAllNodeStringValue( value );
     if (propertyType==STRING) 
-      return stringToAllNodeProperty(getLocalProxy<StringProxy>(clusterIndex[clusterId],propertyName), value);
+      return clusterIndex[clusterId]->getLocalProperty<StringProxy>(propertyName)->setAllNodeStringValue( value );
     return false;
     //cer << "..ok" << endl;
   }
-  bool setAllEdgeValue(int clusterId, const string &propertyType, const string &propertyName, string value)
-  {
+  bool setAllEdgeValue(int clusterId, const string &propertyType, const string &propertyName, string value) {
     //cerr << "setAllEdgeValue.." << endl;
     bool result=false;
 
@@ -231,55 +193,51 @@ struct TLPGraphBuilder:public TLPTrue
       char *endPtr=0;
       const char *startPtr=value.c_str();
       int result=strtol(startPtr,&endPtr,10);
-      if (endPtr==startPtr) return false;
+      if (endPtr==startPtr) result = 0; //return false;
       if (clusterIndex.find(result)==clusterIndex.end()) return false;
       if (result==0)
-	getLocalProxy<MetaGraphProxy>(clusterIndex[clusterId],propertyName)->setAllEdgeValue(0);
+	clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setAllEdgeValue(0);
       else
-	getLocalProxy<MetaGraphProxy>(clusterIndex[clusterId],propertyName)->setAllEdgeValue(clusterIndex[result]);
+	clusterIndex[clusterId]->getLocalProperty<MetaGraphProxy>(propertyName)->setAllEdgeValue(clusterIndex[result]);
       return true;
     }
     if (propertyType==METRIC) 
-      result= stringToAllEdgeProperty( getLocalProxy<MetricProxy>(clusterIndex[clusterId], propertyName) , value);
+      result= clusterIndex[clusterId]->getLocalProperty<MetricProxy>(propertyName)->setAllEdgeStringValue( value );
     if (propertyType==LAYOUT) 
-      result= stringToAllEdgeProperty(getLocalProxy<LayoutProxy>(clusterIndex[clusterId], propertyName) , value);
+      result= clusterIndex[clusterId]->getLocalProperty<LayoutProxy>(propertyName)->setAllEdgeStringValue( value );
     if (propertyType==SIZE) 
-      result= stringToAllEdgeProperty( getLocalProxy<SizesProxy>(clusterIndex[clusterId], propertyName) , value);
+      result= clusterIndex[clusterId]->getLocalProperty<SizesProxy>(propertyName)->setAllEdgeStringValue( value );
     if (propertyType==COLOR) 
-      result= stringToAllEdgeProperty(getLocalProxy<ColorsProxy>(clusterIndex[clusterId], propertyName) , value);
+      result= clusterIndex[clusterId]->getLocalProperty<ColorsProxy>(propertyName)->setAllEdgeStringValue( value );
     if (propertyType==INT) 
-      result= stringToAllEdgeProperty(getLocalProxy<IntProxy>(clusterIndex[clusterId], propertyName) , value);
+      result= clusterIndex[clusterId]->getLocalProperty<IntProxy>(propertyName)->setAllEdgeStringValue( value );
     if (propertyType==BOOL) 
-      result= stringToAllEdgeProperty(getLocalProxy<SelectionProxy>(clusterIndex[clusterId], propertyName) , value);
+      result= clusterIndex[clusterId]->getLocalProperty<SelectionProxy>(propertyName)->setAllEdgeStringValue( value );
     if (propertyType==STRING) 
-      result= stringToAllEdgeProperty(getLocalProxy<StringProxy>(clusterIndex[clusterId], propertyName) , value);
+      result= clusterIndex[clusterId]->getLocalProperty<StringProxy>(propertyName)->setAllEdgeStringValue( value );
     //cer<< "..ok result=" << result<< endl;
     return result;
   }
-  bool addCluster(int id, const string&name, int fatherId=0)
-  {
-    //    //cer << "TLPGraphBuilder::Add Cluster " << name << endl;
-    SelectionProxy *selProxy=getLocalProxy<SelectionProxy>(clusterIndex[fatherId],"tmpSelection");
+  bool addCluster(int id, const string&name, int fatherId=0) {
+    SelectionProxy *selProxy=clusterIndex[fatherId]->getLocalProperty<SelectionProxy>("tmpSelection");
     selProxy->setAllNodeValue(false);
     selProxy->setAllEdgeValue(false);
-    subGraphIndex[id]=clusterIndex[fatherId]->addView(name,selProxy);
-    clusterIndex[id]=subGraphIndex[id]->getAssociatedSuperGraph();
-    clusterIndex[fatherId]->getPropertyProxyContainer()->delLocalProxy("tmpSelection");
+    clusterIndex[id]=clusterIndex[fatherId]->addSubGraph(selProxy);
+    clusterIndex[id]->setAttribute("name",name);
+    clusterIndex[fatherId]->delLocalProperty("tmpSelection");
     return true;
   }
   bool addStruct(const string& structName,TLPBuilder*&newBuilder) ;
 };
 //=================================================================================
-struct TLPNodeBuilder:public TLPFalse
-{
+struct TLPNodeBuilder:public TLPFalse {
   TLPGraphBuilder *graphBuilder;
   TLPNodeBuilder(TLPGraphBuilder *graphBuilder):graphBuilder(graphBuilder){}
   bool addInt(const int id) {return graphBuilder->addNode(id);}
   bool close(){return true;}
 };
 //=================================================================================
-struct TLPEdgeBuilder:public TLPFalse
-{
+struct TLPEdgeBuilder:public TLPFalse {
   TLPGraphBuilder *graphBuilder;
   int parameter[3];
   int nbParameter;
@@ -302,24 +260,18 @@ struct TLPEdgeBuilder:public TLPFalse
   }
 };
 //=================================================================================
-struct TLPClusterBuilder:public TLPFalse
-{
+struct TLPClusterBuilder:public TLPFalse {
   TLPGraphBuilder *graphBuilder;
   int clusterId,fatherId;
-  //  string clusterName;
   TLPClusterBuilder(TLPGraphBuilder *graphBuilder,int father=0):graphBuilder(graphBuilder),fatherId(father){}
   bool addInt(const int id) {
-    //cer << "TLPClusterBuilder::cluster id " << id << endl;
     clusterId=id;
     return true;
   }
   bool addString(const string &str) {
-    //cer << "TLPClusterBuilder::cluster name " << str << endl;
-    //    clusterName=str;
     return graphBuilder->addCluster(clusterId , str, fatherId);
   }
   bool addStruct(const string& structName,TLPBuilder*&newBuilder);
-  
   bool addNode (int nodeId) {
     return graphBuilder->addClusterNode(clusterId,nodeId);
   }
@@ -329,24 +281,21 @@ struct TLPClusterBuilder:public TLPFalse
   bool close(){return true;}
 };
 //=================================================================================
-struct TLPClusterNodeBuilder:public TLPFalse
-{
+struct TLPClusterNodeBuilder:public TLPFalse {
   TLPClusterBuilder *clusterBuilder;
   TLPClusterNodeBuilder(TLPClusterBuilder *clusterBuilder):clusterBuilder(clusterBuilder){}
   bool addInt(const int id) {return clusterBuilder->addNode(id);}
   bool close(){return true;}
 };
 //=================================================================================
-struct TLPClusterEdgeBuilder:public TLPFalse
-{
+struct TLPClusterEdgeBuilder:public TLPFalse {
   TLPClusterBuilder *clusterBuilder;
   TLPClusterEdgeBuilder(TLPClusterBuilder *clusterBuilder):clusterBuilder(clusterBuilder){}
   bool addInt(const int id) {return clusterBuilder->addEdge(id);}
   bool close(){return true;}
 };
 //================================================================================
-struct TLPDisplayingBuilder: public TLPFalse
-{
+struct TLPDisplayingBuilder: public TLPFalse {
   TLPGraphBuilder *graphBuilder;
   DataSet dataSet;
   
@@ -361,48 +310,6 @@ struct TLPDisplayingBuilder: public TLPFalse
   }
 };
 //================================================================================
-struct TLPGlyphBuilder: public TLPFalse
-{
-  TLPDisplayingBuilder *displayingBuilder;
-  STL_EXT_NS::hash_map<int, string, STL_EXT_NS::hash<int> > glyphTable;
-  int glyphIndex;
-
-  TLPGlyphBuilder(TLPDisplayingBuilder *displayingBuilder) :
-    displayingBuilder(displayingBuilder) {
-    displayingBuilder->dataSet.get<STL_EXT_NS::hash_map<int, string, STL_EXT_NS::hash<int> > >("glyphTable", glyphTable);
-  }
-  virtual ~TLPGlyphBuilder(){}
-  
-  bool addInt(const int id) {glyphIndex=id; return true;}
-  bool addStruct(const string& structName, TLPBuilder*&newBuilder);
-  bool close(){
-    displayingBuilder->dataSet.set("glyphTable", glyphTable);
-    return true;
-  }
-  bool setPlugin(const string &val) {
-    if (glyphIndex >= 0) {
-      glyphTable[glyphIndex] = val;
-    }
-#ifndef NDEBUG
-    else {
-      cerr << "TLPGlyphBuilder::setPlugin(" << val << "): glyphIndex=" << glyphIndex << ", Ignored insertion" << endl;
-    }
-#endif
-    return true;
-  }
-};
-//================================================================================
-struct TLPPluginBuilder: public TLPFalse
-{
-  TLPGlyphBuilder *glyphBuilder;
-
-  TLPPluginBuilder(TLPGlyphBuilder *glyphBuilder) : glyphBuilder(glyphBuilder){}
-  virtual ~TLPPluginBuilder(){}
-
-  bool addString(const string&val) {return glyphBuilder->setPlugin(val);}
-  bool close(){return true;}
-};
-//=================================================================================
 struct TLPDisplayingPropertyBuilder : public TLPFalse
 {
   TLPDisplayingBuilder *displayingBuilder;
@@ -422,13 +329,15 @@ struct TLPDisplayingPropertyBuilder : public TLPFalse
     case 1: {
       if (type==COLOR) {
 	Color c;
-	if (stringToColor(const_cast<string &>(val), c)) data->set(prop, c);
+	if ( ColorType::fromString(c,val) )
+		data->set(prop, c);
 	else cerr << __PRETTY_FUNCTION__ << ": COLOR failed" << endl;
 	//else return false;
       }
       else if (type==COORD) {
 	Coord c;
-	if (stringToCoord(const_cast<string &>(val), c)) data->set(prop, c);
+	if ( PointType::fromString(c,val) )
+		data->set(prop, c);
 	else cerr << __PRETTY_FUNCTION__ << ": COORD failed" << endl;
 	//else return false;
       }
@@ -486,17 +395,14 @@ struct TLPDisplayingPropertyBuilder : public TLPFalse
 //=================================================================================
 bool TLPClusterBuilder::addStruct(const string& structName,TLPBuilder*&newBuilder)   { 
     if (structName==CLUSTERNODES) {
-      //cer << "TLPClusterBuilder::new nodes" << structName << endl;
       newBuilder=new TLPClusterNodeBuilder(this);
     }
     else
       if (structName==CLUSTEREDGES) {
-	//cer << "TLPClusterBuilder::new edgess" << structName << endl;
 	newBuilder=new TLPClusterEdgeBuilder(this);
       }
       else
 	if (structName==CLUSTER) {
-	  //cer << "TLPClusterBuilder::new cluster" << structName << endl;
 	  newBuilder=new TLPClusterBuilder(graphBuilder,clusterId);
 	}
 	else {
@@ -504,10 +410,9 @@ bool TLPClusterBuilder::addStruct(const string& structName,TLPBuilder*&newBuilde
 	  return false;
 	}
     return true; 
-  }
+}
 //=================================================================================
-struct TLPPropertyBuilder:public TLPFalse
-{
+struct TLPPropertyBuilder:public TLPFalse {
   TLPGraphBuilder *graphBuilder;
   int clusterId;
   string propertyType,propertyName;
@@ -545,8 +450,7 @@ struct TLPPropertyBuilder:public TLPFalse
   bool close(){return true;}
 };
 //=================================================================================
-struct TLPNodePropertyBuilder:public TLPFalse
-{
+struct TLPNodePropertyBuilder:public TLPFalse {
   TLPPropertyBuilder *propertyBuilder;
   int nodeId;
   TLPNodePropertyBuilder(TLPPropertyBuilder *propertyBuilder):propertyBuilder(propertyBuilder){}
@@ -557,9 +461,7 @@ struct TLPNodePropertyBuilder:public TLPFalse
   bool close(){return true;}
 };
 //=================================================================================
-struct TLPEdgePropertyBuilder:public TLPFalse
-{
-
+struct TLPEdgePropertyBuilder:public TLPFalse {
   TLPPropertyBuilder *propertyBuilder;
   int edgeId;
   string nodeValue;
@@ -571,8 +473,7 @@ struct TLPEdgePropertyBuilder:public TLPFalse
   {return propertyBuilder->setEdgeValue(edgeId,val);}
   bool close(){return true;}
 };
-struct TLPDefaultPropertyBuilder:public TLPFalse
-{
+struct TLPDefaultPropertyBuilder:public TLPFalse {
   TLPPropertyBuilder *propertyBuilder;
   int edgeId;
   string nodeValue;
@@ -588,8 +489,7 @@ struct TLPDefaultPropertyBuilder:public TLPFalse
   bool close(){return true;}
 };
 //=================================================================================
-bool TLPPropertyBuilder::addStruct(const string& structName,TLPBuilder*&newBuilder) 
-{
+bool TLPPropertyBuilder::addStruct(const string& structName,TLPBuilder*&newBuilder) {
   if (structName==DEFAULTVALUE) {
     newBuilder= new TLPDefaultPropertyBuilder(this);
     return true;
@@ -607,8 +507,7 @@ bool TLPPropertyBuilder::addStruct(const string& structName,TLPBuilder*&newBuild
   return false; 
 }
 //=================================================================================
-bool TLPGraphBuilder::addStruct(const string& structName,TLPBuilder*&newBuilder) 
-{
+bool TLPGraphBuilder::addStruct(const string& structName,TLPBuilder*&newBuilder) {
   if (structName==NODES) {
     newBuilder=new TLPNodeBuilder(this);
   }
@@ -629,14 +528,10 @@ bool TLPGraphBuilder::addStruct(const string& structName,TLPBuilder*&newBuilder)
   return true;
 }
 //================================================================================
-bool TLPDisplayingBuilder::addStruct(const string& structName,TLPBuilder*&newBuilder)
-{
-  if (structName==GLYPH) {
-    newBuilder=new TLPGlyphBuilder(this);
-  }
-  else if (structName==COORD || structName==COLOR || structName==BOOL ||
-           structName==INT || structName==UINT || structName==FLOAT ||
-           structName==DOUBLE) {
+bool TLPDisplayingBuilder::addStruct(const string& structName,TLPBuilder*&newBuilder) {
+  if (structName==COORD || structName==COLOR || structName==BOOL ||
+      structName==INT || structName==UINT || structName==FLOAT ||
+      structName==DOUBLE) {
     newBuilder=new TLPDisplayingPropertyBuilder(this, structName);
   }
   else
@@ -644,27 +539,24 @@ bool TLPDisplayingBuilder::addStruct(const string& structName,TLPBuilder*&newBui
   return true;
 }
 //================================================================================
-bool TLPGlyphBuilder::addStruct(const string& structName,TLPBuilder*&newBuilder)
-{
-  if (structName==PLUGIN) {
-    newBuilder=new TLPPluginBuilder(this);
-  }
-  else
-    newBuilder=new TLPTrue();
-  return true;
+namespace {
+  const char * paramHelp[] = {
+    // filename
+    HTML_HELP_OPEN() \
+    HTML_HELP_DEF( "type", "pathname" ) \
+    HTML_HELP_BODY() \
+    "This parameter defines the file pathname to import." \
+    HTML_HELP_CLOSE(),
+  };
 }
-//================================================================================
-//================================================================================
-struct TLPImport:public ImportModule
-{
+/** \addtogroup import */
+/*@{*/
+struct TLPImport:public ImportModule {
 public:
-  
-  TLPImport(ClusterContext context):ImportModule(context)
-  {
-    addParameter<string>("filename");
+  TLPImport(ClusterContext context):ImportModule(context) {
+    addParameter<string>("filename",paramHelp[0]);
     addParameter<DataSet>(DISPLAYING);
   }
-  
   ~TLPImport(){}
   bool import(const string &dummy) {
     string filename;
@@ -672,22 +564,18 @@ public:
     struct stat infoEntry;
     lstat(filename.c_str(),&infoEntry);
     int size=infoEntry.st_size;
-    //cer << "Opening file" << endl;
     istream *input;
     if (filename.rfind(".gz") == (filename.length() - 3))
-      input = new igzstream(filename.c_str());
+      input = tlp::getIgzstream(filename.c_str());
     else
       input = new ifstream(filename.c_str());
     
     TLPParser<true> myParser(*input, new TLPGraphBuilder(superGraph, dataSet),pluginProgress,size);
-    //TLPParser<true> myParser(myFile,new TLPWriter());
     bool result = myParser.parse();
     delete input;
 
-    cerr << "Import Finished" << flush << endl;
     return result;
-    //    return true;
   }
 };
-
+/*@}*/
 IMPORTPLUGIN(TLPImport,"tlp","Auber","16/02/2001","0","0","1");
