@@ -23,7 +23,7 @@
 class Random:public Layout
 { 
 public:
-  Random(PropertyContext *);
+  Random(const PropertyContext &);
   ~Random();
   
   bool run();
