@@ -7,7 +7,7 @@
 class SpringElectrical:public Layout
 { 
 public:
-  SpringElectrical(PropertyContext *);
+  SpringElectrical(const PropertyContext &);
   ~SpringElectrical();
   bool run();
   bool check(std::string &);
