@@ -1,8 +1,12 @@
+
 //-*-c++-*-
 #ifndef _ARITYMETRIC_H
 #define _ARITYMETRIC_H
 
 #include <tulip/TulipPlugin.h>
+
+/** \addtogroup metric */
+/*@{*/
 /// ArityMetric.h - Compute the degree of each node.
 /** This plugin compute the degree of each node
  *
@@ -32,9 +36,9 @@
 class ArityMetric:public Metric
 { 
 public:
-  ArityMetric(PropertyContext *);
+  ArityMetric(const PropertyContext &);
   ~ArityMetric();
   double getNodeValue(const node n);
 };
-
+/*@}*/
 #endif
