@@ -14,17 +14,19 @@
 #include <stack>
 #include <tulip/TulipPlugin.h>
 
-class ConnectedAndTreeComponent:public Metric
-{ 
+/** \addtogroup metric */
+/*@{*/
+class ConnectedAndTreeComponent:public Metric { 
 public:
-  ConnectedAndTreeComponent(PropertyContext *);
+  ConnectedAndTreeComponent(const PropertyContext &);
   ~ConnectedAndTreeComponent();
-  int  attachNumerotation(node, STL_EXT_NS::hash_map<node,bool> &, STL_EXT_NS::hash_map<node,bool> &,
-			  STL_EXT_NS::hash_map<node,int> &, int &, std::stack<node> &, int &);
-  void treeRenum(node, std::map<int,int> &);
   bool run();
+private:
+  int  attachNumerotation(node, stdext::hash_map<node,bool> &, stdext::hash_map<node,bool> &,
+			  stdext::hash_map<node,int> &, int &, std::stack<node> &, int &);
+  void treeRenum(node, std::map<int,int> &);
 };
-
+/*@}*/
 #endif
 
 
