@@ -9,6 +9,8 @@
 #endif
 
 #include <tulip/TulipPlugin.h>
+/** \addtogroup metric */
+/*@{*/
 /// StrongComponent.h - An implementation of the Stongly connected component algorithm.
 /** This plugin is an implementation of the Stongly connected algorithm.
  *
@@ -37,12 +39,12 @@
 class ConnectedComponent:public Metric
 { 
 public:
-  ConnectedComponent(PropertyContext *);
+  ConnectedComponent(const PropertyContext &);
   ~ConnectedComponent();
   bool run();
 
 private:
-  void dfs(node n, STL_EXT_NS::hash_map<node,bool> &flag,double value);
+  void dfs(node n, stdext::hash_map<node,bool> &flag,double value);
 };
-
+/*@}*/
 #endif
