@@ -4,17 +4,14 @@
 
 METRICPLUGIN(IdMetric,"Id","David Auber","06/04/2000","Alpha","0","1");
 
-IdMetric::IdMetric(PropertyContext *context):Metric(context) 
-{}
+IdMetric::IdMetric(const PropertyContext &context):Metric(context) {}
 
 IdMetric::~IdMetric() {}
 
-double IdMetric::getEdgeValue(const edge e )
-{
+double IdMetric::getEdgeValue(const edge e ) {
   return e.id;
 }
-double IdMetric::getNodeValue(const node n )
-{
+double IdMetric::getNodeValue(const node n ) {
   return n.id;
 }
 
