@@ -17,7 +17,7 @@
 class IdMetric:public Metric
 { 
 public:
-  IdMetric(PropertyContext *);
+  IdMetric(const PropertyContext &);
   ~IdMetric();
   double getNodeValue(const node n);
   double getEdgeValue(const edge n);
