@@ -13,12 +13,11 @@
 #define _LEAFMETRIC_H
 
 #include <tulip/TulipPlugin.h>
-///
-class LeafMetric:public Metric
-{ 
 
+///
+class LeafMetric:public Metric { 
 public:
-  LeafMetric(PropertyContext *);
+  LeafMetric(const PropertyContext &);
   ~LeafMetric();
   double getNodeValue(const node n);
   bool check(std::string &);
