@@ -18,7 +18,7 @@ class NodeMetric:public Metric
 { 
 
 public:
-  NodeMetric(PropertyContext *);
+  NodeMetric(const PropertyContext &);
   ~NodeMetric();
   double getNodeValue(const node n);
   bool check(std::string &);
