@@ -2,13 +2,12 @@
 
 METRICPLUGIN(RandomMetric,"Random","David Auber","04/10/2001","Alpha","0","1")
 
-RandomMetric::RandomMetric(PropertyContext *context):Metric(context) 
+RandomMetric::RandomMetric(const PropertyContext &context):Metric(context) 
 {}
 
 RandomMetric::~RandomMetric() {}
 
-double RandomMetric::getNodeValue(const node n )
-{
+double RandomMetric::getNodeValue(const node n ) {
   return (double)rand();
 }
 
