@@ -1,9 +1,11 @@
 //-*-c++-*-
 #ifndef _STRENGTHMETRIC_H
 #define _STRENGTHMETRIC_H
-#include <set>
+#include <ext/hash_set>
 #include <tulip/TulipPlugin.h>
 
+/** \addtogroup metric */
+/*@{*/
 /// StrengthMetric.h - An implementation of the strength parameter.
 /** This plugin is an implementation of the Strength Parameter.
  *  algorithm first published in :
@@ -34,15 +36,16 @@
  */
 class StrengthMetric:public Metric { 
 public:
-  StrengthMetric(PropertyContext *);
+  StrengthMetric(const PropertyContext &);
   ~StrengthMetric();
   double getNodeValue(const node n);
   double getEdgeValue(const edge n);
   bool run();
 private:
-  double e(std::set<node> &U);
-  double e(std::set<node> &U,std::set<node> &V);
-  double s(std::set<node> &U,std::set<node> &V);
-  double s(std::set<node> &U);
+  double e(const stdext::hash_set<node> &U);
+  double e(const stdext::hash_set<node> &U,const stdext::hash_set<node> &V);
+  double s(const stdext::hash_set<node> &U,const stdext::hash_set<node> &V);
+  double s(const stdext::hash_set<node> &U);
 };
+/*@}*/
 #endif
