@@ -1,16 +1,16 @@
+#include <tulip/AcyclicTest.h>
 #include "Viennot.h"
 
 METRICPLUGIN(ViennotMetric,"Viennot","David Auber","04/10/2001","Alpha","0","1");
 
 using namespace std;
 
-ViennotMetric::ViennotMetric(PropertyContext *context):Metric(context) 
+ViennotMetric::ViennotMetric(const PropertyContext &context):Metric(context) 
 {}
 
 ViennotMetric::~ViennotMetric() {}
 
-double ViennotMetric::getNodeValue(const node n )
-{
+double ViennotMetric::getNodeValue(const node n ) {
   if (superGraph->outdeg(n)==0) return 1;
   double valMax=-1;
   unsigned int nbValMax=0;
@@ -34,7 +34,7 @@ double ViennotMetric::getNodeValue(const node n )
 
 
 bool ViennotMetric::check(string &err) {
-  if (superGraph->isAcyclic()) {
+  if (AcyclicTest::isAcyclic(superGraph)) {
     return true;
   }
   else {
