@@ -8,7 +8,7 @@ class InducedSubGraphSelection:public Selection
 { 
 public:
   ///
-  InducedSubGraphSelection(PropertyContext *);
+  InducedSubGraphSelection(const PropertyContext &);
   ///
   ~InducedSubGraphSelection();
   ///
