@@ -1,22 +1,17 @@
 //-*-c++-*-
 #ifndef Tulip_LabelSelection_H
 #define Tulip_LabelSelection_H
-
+#include <string>
 #include <tulip/TulipPlugin.h>
-///
-class LabelSelection:public Selection
-{ 
+
+class LabelSelection:public Selection { 
 public:
-  ///
-  LabelSelection(PropertyContext *);
-  ///
+  LabelSelection(const PropertyContext &);
   ~LabelSelection();
-  ///
-  bool run();
+  bool check(std::string &errMsg);
   bool getNodeValue(node n);
-  bool getEdgeValue(edge e);
+
 private:
-  bool cancelPressed;
   StringProxy *stringProxy;
   std::vector<std::string> *searchStrings;
   bool searchType;
