@@ -16,16 +16,11 @@ SELECTIONPLUGIN(LoopSelection,"Loop Selection","David Auber","20/01/2003","Alpha
 
 using namespace std;
 
-LoopSelection::LoopSelection(PropertyContext *context):Selection(context) 
-{}
+LoopSelection::LoopSelection(const PropertyContext &context):Selection(context) {}
 
-LoopSelection::~LoopSelection() {
-}
+LoopSelection::~LoopSelection() {}
 
 bool LoopSelection::getEdgeValue(edge e) {
   return (superGraph->source(e)==superGraph->target(e));
 }
 
-bool LoopSelection::run() {
-  return true;
-}
