@@ -3,19 +3,20 @@
 #define Tulip_LoopSelection_H
 
 #include <tulip/TulipPlugin.h>
+
+/** \addtogroup selection */
+/*@{*/
 ///
-class LoopSelection:public Selection
-{ 
+class LoopSelection:public Selection { 
 public:
   ///
-  LoopSelection(PropertyContext *);
+  LoopSelection(const PropertyContext &);
   ///
   ~LoopSelection();
   ///
-  bool run();
   bool getEdgeValue(edge e);
 };
-
+/*@}*/
 #endif
 
 
