@@ -4,24 +4,28 @@
 
 #include <tulip/TulipPlugin.h>
 
-///
-class SpanningDagSelection:public Selection
-{ 
 
+/** \addtogroup selection */
+/*@{*/
+///
+
+class SpanningDagSelection:public Selection { 
 
 public:
   ///
-  SpanningDagSelection(PropertyContext *);
+  SpanningDagSelection(const PropertyContext &);
   ///
   ~SpanningDagSelection();
   ///
   bool run();
   ///
-  void dfsAcyclicTest(const node &,SelectionProxy *,SelectionProxy *);
-  ///
   bool check(std::string &);
   ///
   void reset();
-};
 
+private :
+  ///
+  void dfsAcyclicTest(const node &,SelectionProxy *,SelectionProxy *);
+};
+/*@}*/
 #endif
