@@ -11,7 +11,7 @@ class SpanningTreeSelection:public Selection
 
 public:
   ///
-  SpanningTreeSelection(PropertyContext *);
+  SpanningTreeSelection(const PropertyContext &);
   ///
   ~SpanningTreeSelection();
   ///
