@@ -8,7 +8,7 @@ using namespace std;
 
 class IdLabels:public String { 
 public:
-  IdLabels(PropertyContext *context):String(context){}
+  IdLabels(const PropertyContext &context):String(context){}
   ~IdLabels(){}
   string getNodeValue(const node n) {
     char tmp[255];
