@@ -12,7 +12,7 @@ class MyProgress:public QWidget,public PluginProgress {
 public:
   MyProgress(QWidget* parent,std::string text);
   virtual ~MyProgress();
-  bool progress(int i,int j);
+  bool progress_handler(int i,int j);
 public slots:
   void stopCompute();
 public:
